@@ -12,20 +12,21 @@ from contextlib import contextmanager, ExitStack
 from unittest.mock import Mock, patch
 from typing import List, Optional, TypeVar, Type
 
-import sip
-
 from AnyQt.QtCore import Qt, QObject, pyqtSignal, QElapsedTimer, pyqtSlot
 from AnyQt.QtTest import QTest, QSignalSpy
 from AnyQt.QtWidgets import (
     QApplication, QComboBox, QSpinBox, QDoubleSpinBox, QSlider
 )
+from AnyQt import sip
 
 from orangewidget.report.owreport import OWReport
 from orangewidget.settings import SettingsHandler
-from orangewidget.utils.signals import get_input_meta, notify_input_helper
+from orangewidget.utils.signals import get_input_meta, notify_input_helper, \
+    Output, Input
 from orangewidget.widget import OWBaseWidget
 
-sip.setdestroyonexit(False)
+if hasattr(sip, "setdestroyonexit"):
+    sip.setdestroyonexit(False)
 
 app = None
 
@@ -158,6 +159,7 @@ class GuiTest(unittest.TestCase):
     GuiTest ensures that a QApplication exists before tests are run an
     """
     tear_down_stack: ExitStack
+    LANGUAGE = "English"
 
     @classmethod
     def setUpClass(cls):
@@ -181,6 +183,10 @@ class GuiTest(unittest.TestCase):
             else:
                 appnope.nope()
         cls.tear_down_stack = ExitStack()
+        if "pyqtgraph" in sys.modules:
+            # undo pyqtgraph excepthook override, abort on exceptions in
+            # slots, event handlers, ...
+            sys.excepthook = sys.__excepthook__
         super().setUpClass()
 
     @classmethod
@@ -192,6 +198,29 @@ class GuiTest(unittest.TestCase):
         super().tearDownClass()
         QTest.qWait(0)
 
+    def tearDown(self) -> None:
+        """
+        Process any pending events before the next test is executed. This
+        includes deletes scheduled with `QObject.deleteLater`.
+        """
+        super().tearDown()
+        QTest.qWait(0)
+
+    @classmethod
+    def skipNonEnglish(cls, f):
+        return cls.runOnLanguage("English")(f)
+
+    @classmethod
+    def runOnLanguage(cls, lang):
+        def decorator(f):
+            if cls.LANGUAGE != lang:
+                f = unittest.skip(f"Test is valid only for {lang} release")(f)
+            return f
+        return decorator
+
+
+NO_VALUE = object()
+
 
 class WidgetTest(GuiTest):
     """Base class for widget tests
@@ -205,7 +234,6 @@ class WidgetTest(GuiTest):
     widgets = []  # type: List[OWBaseWidget]
 
     def __init_subclass__(cls, **kwargs):
-
         def test_minimum_size(self):
             widget = getattr(self, "widget", None)
             if widget is None:
@@ -242,6 +270,7 @@ class WidgetTest(GuiTest):
             nonlocal report
             if report is None:
                 report = OWReport()
+                report.have_report_warning_shown = True  # if missing QtWebView/QtWebKit
                 if not (os.environ.get("TRAVIS") or os.environ.get("APPVEYOR")):
                     report.show = Mock()
                 cls.widgets.append(report)
@@ -269,7 +298,6 @@ class WidgetTest(GuiTest):
     def tearDown(self):
         """Process any pending events before the next test is executed."""
         self.signal_manager.clear()
-        QTest.qWait(0)
         super().tearDown()
 
     def create_widget(self, cls, stored_settings=None, reset_default_settings=True):
@@ -384,7 +412,7 @@ class WidgetTest(GuiTest):
         widget.show()
         app.exec()
 
-    def send_signal(self, input, value, *args, widget=None, wait=-1):
+    def send_signal(self, input, value=NO_VALUE, *args, widget=None, wait=-1):
         """ Send signal to widget by calling appropriate triggers.
 
         Parameters
@@ -398,6 +426,13 @@ class WidgetTest(GuiTest):
         wait : int
             The amount of time to wait for the widget to complete.
         """
+        if value is NO_VALUE:
+            value = input
+            wid = widget or self.widget
+            inputs = wid.inputs or wid.Inputs.__dict__.values()
+            assert len(inputs) == 1
+            input = next(iter(inputs))
+
         return self.send_signals([(input, value)], *args,
                                  widget=widget, wait=wait)
 
@@ -505,7 +540,7 @@ class WidgetTest(GuiTest):
             widget.unconditional_commit()
         self.wait_until_finished(widget=widget, timeout=wait)
 
-    def get_output(self, output, widget=None, wait=DEFAULT_TIMEOUT):
+    def get_output(self, output=None, widget=None, wait=DEFAULT_TIMEOUT):
         """Return the last output that has been sent from the widget.
 
         Parameters
@@ -525,10 +560,13 @@ class WidgetTest(GuiTest):
             # In this case, we use `self.widget`.
             widget = getattr(output, "widget", self.widget) or self.widget
 
-        if not isinstance(output, str):
+        outputs = widget.outputs or widget.Outputs.__dict__.values()
+        if output is None:
+            assert len(outputs) == 1
+            output = next(iter(outputs)).name
+        elif not isinstance(output, str):
             output = output.name
         # widget.outputs are old-style signals; if empty, use new style
-        outputs = widget.outputs or widget.Outputs.__dict__.values()
         assert output in (out.name for out in outputs), \
             "widget {} has no output {}".format(widget.name, output)
         return widget.signalManager.get_output(widget, output, wait)
@@ -608,6 +646,26 @@ class TestWidgetTest(WidgetTest):
         self.check_msg_base_class(C())  # It is unfortunate that this passes...
         self.assertRaises(AssertionError, self.check_msg_base_class, D())
 
+    def test_get_single_output(self):
+        class A(OWBaseWidget):
+            name = "A"
+
+            class Inputs(OWBaseWidget.Inputs):
+                question = Input("Question", str, auto_summary=False)
+
+            class Outputs(OWBaseWidget.Outputs):
+                answer = Output("Answer", int, auto_summary=False)
+
+            @Inputs.question
+            def question(self, s):
+                self.Outputs.answer.send(eval(s))
+
+        self.widget = self.create_widget(A)
+
+        self.assertIsNone(self.get_output())
+        self.send_signal("6 * 7")
+        self.assertEquals(self.get_output(), 42)
+
 
 class BaseParameterMapping:
     """Base class for mapping between gui components and learner's parameters
